package cc.toph.simplycompat.compat;

import cc.toph.simplycompat.registry.ConfigRegistry;
import cc.toph.simplycompat.util.ToolMaterials;
import dqu.additionaladditions.AdditionalAdditions;
import dqu.additionaladditions.material.GildedNetheriteToolMaterial;
import dqu.additionaladditions.material.RoseGoldToolMaterial;
import net.minecraft.core.registries.BuiltInRegistries;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.world.item.Items;
import net.minecraft.world.item.crafting.Ingredient;
import org.jetbrains.annotations.NotNull;

public enum AdditionalAdditionsToolMaterials implements ToolMaterials<AdditionalAdditionsToolMaterials> {
    /**
     * See {@link RoseGoldToolMaterial}
     */
    ROSE_GOLD(
            2,
            900,
            9.0f,
            2.0F,
            ConfigRegistry.WEAPON_ATTRIBUTES.ROSE_GOLD,
            17,
            ConfigRegistry.WEAPON_ATTRIBUTES.ROSE_GOLD_ENABLED,
            new ResourceLocation(AdditionalAdditions.namespace, "rose_gold_alloy")
    ),
    /**
     * See {@link GildedNetheriteToolMaterial}
     */
    GILDED_NETHERITE(
            4,
            2031,
            10.0F,
            4.5F,
            ConfigRegistry.WEAPON_ATTRIBUTES.ROSE_GOLD,
            20,
            ConfigRegistry.WEAPON_ATTRIBUTES.ROSE_GOLD_ENABLED,
            Items.NETHERITE_INGOT.arch$registryName()
    );

    private final int level;
    private final int uses;
    private final float speed;
    private final float attackDamageBonus;
    private final float damageModifier;
    private final int enchantmentValue;
    private final boolean enabled;
    private final ResourceLocation repairIngredient;

    AdditionalAdditionsToolMaterials(
            int level,
            int uses,
            float speed,
            float attackDamageBonus,
            float damageModifier,
            int enchantmentValue,
            boolean enabled,
            ResourceLocation repairIngredient
    ) {
        this.level = level;
        this.uses = uses;
        this.speed = speed;
        this.attackDamageBonus = attackDamageBonus;
        this.enchantmentValue = enchantmentValue;
        this.damageModifier = damageModifier;
        this.enabled = enabled;
        this.repairIngredient = repairIngredient;
    }

    @Override
    public String getName() {
        return this.name().toLowerCase();
    }

    @Override
    public String getIdentifier() {
        return repairIngredient.toString();
    }

    @Override
    public int getUses() {
        return uses;
    }

    @Override
    public float getSpeed() {
        return speed;
    }

    @Override
    public float getAttackDamageBonus() {
        return attackDamageBonus;
    }

    @Override
    public float getDamageModifier() {
        return damageModifier;
    }

    @Override
    public int getLevel() {
        return level;
    }

    @Override
    public int getEnchantmentValue() {
        return enchantmentValue;
    }

    @Override
    public boolean isEnabled() {
        return enabled;
    }

    @Override
    public @NotNull Ingredient getRepairIngredient() {
        return Ingredient.of(BuiltInRegistries.ITEM.get(repairIngredient));
    }

    @Override
    public AdditionalAdditionsToolMaterials[] getValues() {
        return values();
    }


}