package cc.toph.simplycompat.compat;

import cc.toph.simplycompat.registry.ConfigRegistry;
import cc.toph.simplycompat.util.ToolMaterials;
import net.minecraft.core.registries.BuiltInRegistries;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.world.item.Items;
import net.minecraft.world.item.crafting.Ingredient;
import net.purejosh.purecoppertools.PurecoppertoolsMod;
import org.jetbrains.annotations.NotNull;

public enum PureCopperToolMaterials implements ToolMaterials<PureCopperToolMaterials> {
    COPPER(
            0,
            184,
            3.0F,
            1.5f,
            ConfigRegistry.WEAPON_ATTRIBUTES.COPPER,
            22,
            ConfigRegistry.WEAPON_ATTRIBUTES.COPPER_ENABLED,
            Items.COPPER_INGOT.arch$registryName()

    ),
    EXPOSED_COPPER(
            0,
            218,
            3.0f,
            2.0f,
            ConfigRegistry.WEAPON_ATTRIBUTES.EXPOSED_COPPER,
            18,
            ConfigRegistry.WEAPON_ATTRIBUTES.EXPOSED_COPPER_ENABLED,
            new ResourceLocation(PurecoppertoolsMod.MODID, "exposed_copper_ingot")

    ),
    WEATHERED_COPPER(
            0,
            258,
            3.5f,
            2.5f,
            ConfigRegistry.WEAPON_ATTRIBUTES.WEATHERED_COPPER,
            14,
            ConfigRegistry.WEAPON_ATTRIBUTES.WEATHERED_COPPER_ENABLED,
            new ResourceLocation(PurecoppertoolsMod.MODID, "weathered_copper_ingot")

    ),
    OXIDIZED_COPPER(
            0,
            304,
            4.0f,
            3.0f,
            ConfigRegistry.WEAPON_ATTRIBUTES.OXIDIZED_COPPER,
            10,
            ConfigRegistry.WEAPON_ATTRIBUTES.OXIDIZED_COPPER_ENABLED,
            new ResourceLocation(PurecoppertoolsMod.MODID, "oxidized_copper_ingot")
    );

    private final int level;
    private final int uses;
    private final float speed;
    private final float attackDamageBonus;
    private final float damageModifier;
    private final int enchantmentValue;
    private final boolean enabled;
    private final ResourceLocation repairIngredient;

    PureCopperToolMaterials(
            int level,
            int uses,
            float speed,
            float attackDamageBonus,
            float damageModifier,
            int enchantmentValue,
            boolean enabled,
            ResourceLocation repairIngredient
    ) {
        this.level = level;
        this.uses = uses;
        this.speed = speed;
        this.attackDamageBonus = attackDamageBonus;
        this.enchantmentValue = enchantmentValue;
        this.damageModifier = damageModifier;
        this.enabled = enabled;
        this.repairIngredient = repairIngredient;
    }

    @Override
    public String getName() {
        return this.name().toLowerCase();
    }

    @Override
    public String getIdentifier() {
        return repairIngredient.toString();
    }

    @Override
    public int getUses() {
        return uses;
    }

    @Override
    public float getSpeed() {
        return speed;
    }

    @Override
    public float getAttackDamageBonus() {
        return attackDamageBonus;
    }

    @Override
    public float getDamageModifier() {
        return damageModifier;
    }

    @Override
    public int getLevel() {
        return level;
    }

    @Override
    public int getEnchantmentValue() {
        return enchantmentValue;
    }

    @Override
    public boolean isEnabled() {
        return enabled;
    }

    @Override
    public @NotNull Ingredient getRepairIngredient() {
        return Ingredient.of(BuiltInRegistries.ITEM.get(repairIngredient));
    }

    @Override
    public PureCopperToolMaterials[] getValues() {
        return values();
    }


}