package cc.toph.simplycompat.compat;

import cc.toph.simplycompat.registry.ConfigRegistry;
import cc.toph.simplycompat.util.ToolMaterials;
import com.drmangotea.tfmg.registry.TFMGItems;
import com.drmangotea.tfmg.registry.TFMGTiers;
import net.minecraft.core.registries.BuiltInRegistries;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.world.item.crafting.Ingredient;
import org.jetbrains.annotations.NotNull;

public enum TFMGToolMaterials implements ToolMaterials<TFMGToolMaterials> {
    ALUMINUM(
            TFMGTiers.ALUMINUM.getLevel(),
            TFMGTiers.ALUMINUM.getUses(),
            TFMGTiers.ALUMINUM.getSpeed(),
            TFMGTiers.ALUMINUM.getAttackDamageBonus(),
            ConfigRegistry.WEAPON_ATTRIBUTES.ALUMINUM,
            TFMGTiers.ALUMINUM.getEnchantmentValue(),
            ConfigRegistry.WEAPON_ATTRIBUTES.ALUMINUM_ENABLED,
            TFMGItems.ALUMINUM_INGOT.getId()
    ),
    LEAD(
            TFMGTiers.LEAD.getLevel(),
            TFMGTiers.LEAD.getUses(),
            TFMGTiers.LEAD.getSpeed(),
            TFMGTiers.LEAD.getAttackDamageBonus(),
            ConfigRegistry.WEAPON_ATTRIBUTES.LEAD,
            TFMGTiers.LEAD.getEnchantmentValue(),
            ConfigRegistry.WEAPON_ATTRIBUTES.LEAD_ENABLED,
            TFMGItems.LEAD_INGOT.getId()
    ),
    STEEL(
            TFMGTiers.STEEL.getLevel(),
            TFMGTiers.STEEL.getUses(),
            TFMGTiers.STEEL.getSpeed(),
            TFMGTiers.STEEL.getAttackDamageBonus(),
            ConfigRegistry.WEAPON_ATTRIBUTES.STEEL,
            TFMGTiers.STEEL.getEnchantmentValue(),
            ConfigRegistry.WEAPON_ATTRIBUTES.STEEL_ENABLED,
            TFMGItems.STEEL_INGOT.getId()
    );

    private final int level;
    private final int uses;
    private final float speed;
    private final float attackDamageBonus;
    private final float damageModifier;
    private final int enchantmentValue;
    private final boolean enabled;
    private final ResourceLocation repairIngredient;

    TFMGToolMaterials(
            int level,
            int uses,
            float speed,
            float attackDamageBonus,
            float damageModifier,
            int enchantmentValue,
            boolean enabled,
            ResourceLocation repairIngredient
    ) {
        this.level = level;
        this.uses = uses;
        this.speed = speed;
        this.attackDamageBonus = attackDamageBonus;
        this.enchantmentValue = enchantmentValue;
        this.damageModifier = damageModifier;
        this.enabled = enabled;
        this.repairIngredient = repairIngredient;


    }

    @Override
    public String getName() {
        return this.name().toLowerCase();
    }

    @Override
    public String getIdentifier() {
        return repairIngredient.toString();
    }

    @Override
    public int getUses() {
        return uses;
    }

    @Override
    public float getSpeed() {
        return speed;
    }

    @Override
    public float getAttackDamageBonus() {
        return attackDamageBonus;
    }

    @Override
    public float getDamageModifier() {
        return damageModifier;
    }

    @Override
    public int getLevel() {
        return level;
    }

    @Override
    public int getEnchantmentValue() {
        return enchantmentValue;
    }

    @Override
    public boolean isEnabled() {
        return enabled;
    }

    @Override
    public @NotNull Ingredient getRepairIngredient() {
        return Ingredient.of(BuiltInRegistries.ITEM.get(repairIngredient));
    }

    @Override
    public TFMGToolMaterials[] getValues() {
        return values();
    }

}