package cc.toph.simplycompat.item;

import cc.toph.simplycompat.registry.ConfigRegistry.WEAPON_ATTRIBUTES;
import cc.toph.simplycompat.util.ToolMaterials;
import net.minecraft.core.registries.BuiltInRegistries;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.world.item.Items;
import net.minecraft.world.item.crafting.Ingredient;
import org.jetbrains.annotations.NotNull;

public enum SimplyCompatToolMaterials implements ToolMaterials<SimplyCompatToolMaterials> {
    COPPER(
            1,
            125,
            4.5F,
            1.0F,
            WEAPON_ATTRIBUTES.COPPER,
            8,
            WEAPON_ATTRIBUTES.COPPER_ENABLED,
            Items.COPPER_INGOT.arch$registryName()
    );

    private final int level;
    private final int uses;
    private final float speed;
    private final float attackDamageBonus;
    private final float damageModifier;
    private final int enchantmentValue;
    private final boolean enabled;
    private final ResourceLocation repairIngredient;

    SimplyCompatToolMaterials(
            int level,
            int uses,
            float speed,
            float attackDamageBonus,
            float damageModifier,
            int enchantmentValue,
            boolean enabled,
            ResourceLocation repairIngredient
    ) {
        this.level = level;
        this.uses = uses;
        this.speed = speed;
        this.attackDamageBonus = attackDamageBonus;
        this.enchantmentValue = enchantmentValue;
        this.damageModifier = damageModifier;
        this.enabled = enabled;
        this.repairIngredient = repairIngredient;
    }


    @Override
    public String getName() {
        return this.name().toLowerCase();
    }

    @Override
    public String getIdentifier() {
        return repairIngredient.toString();
    }

    @Override
    public int getUses() {
        return uses;
    }

    @Override
    public float getSpeed() {
        return speed;
    }

    @Override
    public float getAttackDamageBonus() {
        return attackDamageBonus;
    }

    @Override
    public float getDamageModifier() {
        return damageModifier;
    }

    @Override
    public int getLevel() {
        return level;
    }

    @Override
    public int getEnchantmentValue() {
        return enchantmentValue;
    }

    @Override
    public boolean isEnabled() {
        return enabled;
    }

    @Override
    public @NotNull Ingredient getRepairIngredient() {
        return Ingredient.of(BuiltInRegistries.ITEM.get(repairIngredient));
    }

    @Override
    public SimplyCompatToolMaterials[] getValues() {
        return values();
    }

}
