package cc.toph.simplycompat.registry;

import cc.toph.simplycompat.compat.*;
import cc.toph.simplycompat.util.CompatRecord;
import com.drmangotea.tfmg.CreateTFMG;
import com.simibubi.create.Create;
import create_deep_dark.CreateDeepDarkMod;
import dqu.additionaladditions.AdditionalAdditions;
import net.purejosh.purecoppertools.PurecoppertoolsMod;


/**
 * A registry for compatibility records. Each record represents
 * a supported mod's integration setup.
 *
 * <p>Use {@link #registerAll()} to initialize all integrations.</p>
 */

public final class CompatRegistry {

    /**
     * Compatibility setup for the Create mod.
     */
    public static final CompatRecord<AdditionalAdditionsToolMaterials> ADDITIONAL_ADDITIONS = new CompatRecord<>(
            AdditionalAdditions.namespace,
            "6.0.1",
            AdditionalAdditionsToolMaterials.class
    );

    /**
     * Compatibility setup for the Create mod.
     */
    public static final CompatRecord<CreateToolMaterials> CREATE = new CompatRecord<>(
            Create.ID,
            "0.5.1.j-55",
            CreateToolMaterials.class
    );

    /**
     * Compatibility setup for the Create Deep Dark mod.
     */
    public static final CompatRecord<CreateDeepDarkToolMaterials> CREATE_DEEP_DARK = new CompatRecord<>(
            CreateDeepDarkMod.MODID,
            "1.7.0",
            CreateDeepDarkToolMaterials.class
    );

    /**
     * Compatibility setup for the Create Deep Dark mod.
     */
    public static final CompatRecord<PureCopperToolMaterials> PURE_COPPER = new CompatRecord<>(
            PurecoppertoolsMod.MODID,
            "1.0.1",
            PureCopperToolMaterials.class
    );

    /**
     * Compatibility setup for the TFMG mod.
     */
    public static final CompatRecord<TFMGToolMaterials> TFMG = new CompatRecord<>(
            CreateTFMG.MOD_ID,
            "0.9.3-1.20.1",
            TFMGToolMaterials.class
    );

    /**
     * Initializes all declared compat records.
     */
    public static void registerAll() {
        CompatRegistry.ADDITIONAL_ADDITIONS.register();
        CompatRegistry.PURE_COPPER.register();
        CompatRegistry.CREATE.register();
        CompatRegistry.CREATE_DEEP_DARK.register();
        CompatRegistry.TFMG.register();
    }
}

