package cc.toph.simplycompat.util;

import net.minecraft.world.item.Tier;


/**
 * The ToolMaterials interface outlines the properties and behaviors required
 * for defining custom tool materials. It provides methods for retrieving
 * information about the tool material, such as its name, repair ingredient,
 * base damage modifier, and enabled status.
 * <p>
 * Suggested implementation with Enums
 */
public interface ToolMaterials<E extends Enum<E> & ToolMaterials<E>>
        extends Tier {

    /**
     * Returns the name of the enum constant in lowercase.
     *
     * @return the name of the enum constant as a lowercase string
     */
    String getName();

    /**
     * Returns RepairIngredient ResourceLocation as a string
     *
     * @return String ResourceLocation Path (mod:item)
     */
    String getIdentifier();

    /**
     * Retrieves the base damage modifier associated with the tool material.
     * <p>
     * Simply Swords specific value, not related to {@link Tier#getAttackDamageBonus()}
     *
     * @return the base damage modifier as a float value
     */
    float getDamageModifier();

    /**
     * Checks if Material has been enabled
     *
     * @return boolean
     */
    boolean isEnabled();

    E[] getValues();
}
